# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`rclone`](#rclone): Download and install Rclone

#### Private Classes

* `rclone::install`: Ensures Rclone installed
* `rclone::uninstall`: Removes rclone installed by this module

### Defined types

* [`rclone::config`](#rcloneconfig): General configuration for Rclone.
* [`rclone::config::gdrive`](#rcloneconfiggdrive): Google Drive configuration for Rclone.
* [`rclone::config::s3`](#rcloneconfigs3): S3 configuration for Rclone.

### Functions

#### Public Functions


#### Private Functions

* `rclone::last_version`: Fetches the last released Rclone version from internet

## Classes

### <a name="rclone"></a>`rclone`

Install rclone binary and man page

#### Examples

##### 

```puppet
include rclone
```

#### Parameters

The following parameters are available in the `rclone` class:

* [`ensure`](#ensure)

##### <a name="ensure"></a>`ensure`

Data type: `Pattern[/absent/, /latest/, /\d+\.\d+\.\d+/]`

installed version, can be 'latest', 'absent' or valid version string

Default value: `'latest'`

## Defined types

### <a name="rcloneconfig"></a>`rclone::config`

Ensures Rclone configuration of given name, type and params. Include of `rclone` is required.

#### Examples

##### 

```puppet
rclone::config { 'my_remote':
  os_user => 'my_user',
  type    => 'ftp',
  options => {...}
}
```

#### Parameters

The following parameters are available in the `rclone::config` defined type:

* [`ensure`](#ensure)
* [`os_user`](#os_user)
* [`type`](#type)
* [`options`](#options)
* [`config_name`](#config_name)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

configuration ensure

Default value: `'present'`

##### <a name="os_user"></a>`os_user`

Data type: `String`

operating system user - used to execute rclone commands, effective configuration owner

##### <a name="type"></a>`type`

Data type: `Enum[
    'amazon cloud drive',
    'azureblob',
    'b2',
    'box',
    'crypt',
    'cache',
    'chunker',
    'drive',
    'dropbox',
    'fichier',
    'ftp',
    'google cloud storage',
    'google photos',
    'http',
    'swift',
    'hubic',
    'jottacloud',
    'koofr',
    'local',
    'mailru',
    'mega',
    'memory',
    'onedrive',
    'opendrive',
    'pcloud',
    'premiumizeme',
    'putio',
    'qingstor',
    's3',
    'sftp',
    'sharefile',
    'sugarsync',
    'union',
    'webdav',
    'yandex']`

configuration remote type

##### <a name="options"></a>`options`

Data type: `Hash[String, Optional[String]]`

configuration options - Hash of options for `rclone config` command

##### <a name="config_name"></a>`config_name`

Data type: `String`

configuration name - should be unique among Rclone configurations, defaults to title

Default value: `$title`

### <a name="rcloneconfiggdrive"></a>`rclone::config::gdrive`

Ensures Drive Rclone configuration of given name and params. Include of `rclone` is required.
Support only service account credentials (token authentication requires human interaction when setup).

#### Examples

##### 

```puppet
rclone::config::gdrive { 'drive_remote':
  os_user                     => 'my_user',
  client_id                   => 'SOME_CLIENT_ID',
  client_secret               => 'SOME_CLIENT_SECRET',
  service_account_credentials => 'SERVICE_CREDENTIALS',
}
```

#### Parameters

The following parameters are available in the `rclone::config::gdrive` defined type:

* [`ensure`](#ensure)
* [`os_user`](#os_user)
* [`config_name`](#config_name)
* [`client_id`](#client_id)
* [`client_secret`](#client_secret)
* [`service_account_credentials`](#service_account_credentials)
* [`scope`](#scope)
* [`root_folder_id`](#root_folder_id)
* [`team_drive`](#team_drive)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

configuration ensure

Default value: `'present'`

##### <a name="os_user"></a>`os_user`

Data type: `String`

operating system user - used to execute rclone commands, effective configuration owner

##### <a name="config_name"></a>`config_name`

Data type: `String`

configuration name - should be unique among Rclone configurations, defaults to title

Default value: `$title`

##### <a name="client_id"></a>`client_id`

Data type: `String`

Google drive client_id, maps to Rclone `client_id` property

##### <a name="client_secret"></a>`client_secret`

Data type: `String`

Google drive client_secret, maps to Rclone `client_secret` property

##### <a name="service_account_credentials"></a>`service_account_credentials`

Data type: `String`

Google drive service_account_credentials, maps to Rclone `service_account_credentials` property

##### <a name="scope"></a>`scope`

Data type: `String`

Google drive access scope, maps to Rclone `scope` property

Default value: `'drive'`

##### <a name="root_folder_id"></a>`root_folder_id`

Data type: `Optional[String]`

Id of the drive root folder, maps to Rclone `root_folder_id` property

Default value: ``undef``

##### <a name="team_drive"></a>`team_drive`

Data type: `Optional[String]`

Id of the team drive, maps to Rclone `team_drive` property

Default value: ``undef``

### <a name="rcloneconfigs3"></a>`rclone::config::s3`

Ensures S3 Rclone configuration of given name and params. Include of `rclone` is required.
Currently only AWS provider is supported.

#### Examples

##### 

```puppet
rclone::config::s3 { 's3_remote':
  os_user           => 'my_user',
  access_key_id     => 'SOME_ACCESS_KEY',
  secret_access_key => 'SECRET_ACCESS_KEY',
  region            => 'us-east-1',
}
```

#### Parameters

The following parameters are available in the `rclone::config::s3` defined type:

* [`ensure`](#ensure)
* [`os_user`](#os_user)
* [`config_name`](#config_name)
* [`access_key_id`](#access_key_id)
* [`secret_access_key`](#secret_access_key)
* [`region`](#region)
* [`s3_provider`](#s3_provider)
* [`canned_acl`](#canned_acl)
* [`endpoint`](#endpoint)
* [`location_constraint`](#location_constraint)
* [`location_constraint`](#location_constraint)
* [`server_side_encryption`](#server_side_encryption)
* [`storage_class`](#storage_class)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

configuration ensure

Default value: `'present'`

##### <a name="os_user"></a>`os_user`

Data type: `String`

operating system user - used to execute rclone commands, effective configuration owner

##### <a name="config_name"></a>`config_name`

Data type: `String`

configuration name - should be unique among Rclone configurations, defaults to title

Default value: `$title`

##### <a name="access_key_id"></a>`access_key_id`

Data type: `String`

S3 provider's access_key_id, maps to Rclone `access_key_id` property

##### <a name="secret_access_key"></a>`secret_access_key`

Data type: `String`

S3 provider's secret_access_key, maps to Rclone `secret_access_key` property

##### <a name="region"></a>`region`

Data type: `String`

S3 provider's region, maps to Rclone `region` property

##### <a name="s3_provider"></a>`s3_provider`

Data type: `Enum['AWS']`

S3 provider, maps to Rclone `provider` property

Default value: `'AWS'`

##### <a name="canned_acl"></a>`canned_acl`

Data type: `Optional[String]`

S3 canned ACL, maps to Rclone `acl` property

Default value: ``undef``

##### <a name="endpoint"></a>`endpoint`

Data type: `Optional[String]`

S3 provider's endpoint, maps to Rclone `endpoint` property

Default value: ``undef``

##### <a name="location_constraint"></a>`location_constraint`

Data type: `Optional[String]`

S3 location_constraint, maps to Rclone `location_constraint` property

Default value: ``undef``

##### <a name="location_constraint"></a>`location_constraint`

S3 location_constraint, maps to Rclone `location_constraint` property

Default value: ``undef``

##### <a name="server_side_encryption"></a>`server_side_encryption`

Data type: `Optional[String]`

S3 server_side_encryption, maps to Rclone `server_side_encryption` property

Default value: ``undef``

##### <a name="storage_class"></a>`storage_class`

Data type: `Optional[String]`

S3 storage_class, maps to Rclone `storage_class` property

Default value: ``undef``

## Functions

